.. _spkg_suitesparse:

suitesparse: A suite of sparse matrix software
==============================================

SuiteSparse is a collection of software to deal with sparse matrix. It is
hosted at https://people.engr.tamu.edu/davis/suitesparse.html with source code
now on github at https://github.com/DrTimothyAldenDavis/SuiteSparse

This spkg does a minimal install of suitesparse, only installing the following

-  AMD
-  CAMD
-  COLAMD
-  CCOLAMD
-  CHOLMOD
-  UMFPACK

Those are all the packages needed for cvxopt.

Other configurations are self explanatory.

License: because SuiteSparse is a collection, it comes with a variety of
licenses. Find below a copy of the "LICENSES.txt" shipped with
SuiteSparse.

AMD/Doc/License.txt
-------------------

   AMD, Copyright (c), 1996-2015, Timothy A. Davis,
   Patrick R. Amestoy, and Iain S. Duff. All Rights Reserved.

   Availability:

   http://www.suitesparse.com

   AMD License: BSD 3-clause:

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

-  Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

-  Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

-  Neither the name of the organizations to which the authors are
   affiliated, nor the names of its contributors may be used to endorse
   or promote products derived from this software without specific prior
   written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
   THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
   PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR
   ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
   DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
   HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
   WAY
   OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
   OF SUCH
   DAMAGE.

BTF/Doc/License.txt
-------------------

   BTF, Copyright (C) 2004-2013, University of Florida
   by Timothy A. Davis and Ekanathan Palamadai.
   BTF is also available under other licenses; contact authors for
   details.
   http://www.suitesparse.com

   BTF is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   BTF is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

CAMD/Doc/License.txt
------------------------

   CAMD, Copyright (c) by Timothy A. Davis,
   Yanqing Chen,
   Patrick R. Amestoy, and Iain S. Duff. All Rights Reserved.
   CAMD is available under alternate licenses, contact T. Davis for
   details.

   CAMD License: BSD 3-clause

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

-  Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

-  Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

-  Neither the name of the organizations to which the authors are
   affiliated, nor the names of its contributors may be used to endorse
   or promote products derived from this software without specific prior
   written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
   THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
   PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR
   ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
   DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
   HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
   WAY
   OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
   OF SUCH
   DAMAGE.

   Availability:

   http://www.suitesparse.com

CCOLAMD/Doc/License.txt
-----------------------

   CCOLAMD: constrained column approximate minimum degree ordering
   Copyright (C) 2005-2016, Univ. of Florida. Authors: Timothy A. Davis,
   Sivasankaran Rajamanickam, and Stefan Larimore. Closely based on
   COLAMD by
   Davis, Stefan Larimore, in collaboration with Esmond Ng, and John
   Gilbert.
   http://www.suitesparse.com

   CCOLAMD license: BSD 3-clause:

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

-  Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

-  Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

-  Neither the name of the organizations to which the authors are
   affiliated, nor the names of its contributors may be used to endorse
   or promote products derived from this software without specific prior
   written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
   THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
   PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR
   ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
   DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
   HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
   WAY
   OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
   OF SUCH
   DAMAGE.

CHOLMOD/Doc/License.txt
-----------------------

   ==Check/License.txt==

   CHOLMOD/Check Module. Copyright (C) 2005-2006, Timothy A. Davis
   CHOLMOD is
   also available under other licenses; contact authors for details.
   http://www.suitesparse.com

   Note that this license is for the CHOLMOD/Check module only.
   All CHOLMOD modules are licensed separately.

   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

   ==Cholesky/License.txt==

   CHOLMOD/Cholesky module, Copyright (C) 2005-2006, Timothy A. Davis.
   CHOLMOD is also available under other licenses; contact authors for
   details. http://www.suitesparse.com

   Note that this license is for the CHOLMOD/Cholesky module only.
   All CHOLMOD modules are licensed separately.

   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

   ==Core/License.txt==

   CHOLMOD/Core Module. Copyright (C) 2005-2006, Univ. of Florida.
   Author:
   Timothy A. Davis. CHOLMOD is also available under other licenses;
   contact
   authors for details. http://www.suitesparse.com

   Note that this license is for the CHOLMOD/Core module only.
   All CHOLMOD modules are licensed separately.

   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

   ==Demo/License.txt==

   CHOLMOD/Demo Module. Copyright (C) 2005-2006, Timothy A. Davis.
   CHOLMOD
   is also available under other licenses; contact authors for details.
   http://www.suitesparse.com

   Note that this license is for the CHOLMOD/Demo module only.
   All CHOLMOD modules are licensed separately.

   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
   USA.

   ==Include/License.txt==

   CHOLMOD/Include/\* files. Copyright (C) 2005-2006, either Univ. of
   Florida
   or T. Davis, depending on the file.

   Each file is licensed separately, according to the Module for which
   it
   contains definitions and prototypes:

   Include/cholmod.h LGPL
   Include/cholmod_blas.h LGPL
   Include/cholmod_camd.h part of Partition module
   Include/cholmod_check.h part of Check module
   Include/cholmod_cholesky.h part of Cholesky module
   Include/cholmod_complexity.h LGPL
   Include/cholmod_config.h LGPL
   Include/cholmod_core.h part of Core module
   Include/cholmod_function.h no license; freely usable, no restrictions
   Include/cholmod_gpu.h part of GPU module
   Include/cholmod_gpu_kernels.h part of GPU module
   Include/cholmod_internal.h LGPL
   Include/cholmod_io64.h LGPL
   Include/cholmod_matrixops.h part of MatrixOps module
   Include/cholmod_modify.h part of Modify module
   Include/cholmod_partition.h part of Partition module
   Include/cholmod_supernodal.h part of Supernodal module
   Include/cholmod_template.h LGPL

   ==MATLAB/License.txt==

   CHOLMOD/MATLAB Module. Copyright (C) 2005-2006, Timothy A. Davis.
   CHOLMOD
   is also available under other licenses; contact authors for details.
   MATLAB(tm) is a Registered Trademark of The MathWorks, Inc.
   http://www.suitesparse.com

   Note that this license is for the CHOLMOD/MATLAB module only.
   All CHOLMOD modules are licensed separately.

   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
   USA.

   ==MatrixOps/License.txt==

   CHOLMOD/MatrixOps Module. Copyright (C) 2005-2006, Timothy A. Davis.
   CHOLMOD is also available under other licenses; contact authors for
   details. http://www.suitesparse.com

   Note that this license is for the CHOLMOD/MatrixOps module only.
   All CHOLMOD modules are licensed separately.

   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
   USA.

   ==Modify/License.txt==

   CHOLMOD/Modify Module. Copyright (C) 2005-2006, Timothy A. Davis and
   William W. Hager. CHOLMOD is also available under other licenses;
   contact
   authors for details. http://www.suitesparse.com

   Note that this license is for the CHOLMOD/Modify module only.
   All CHOLMOD modules are licensed separately.

   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
   USA.


   ==Partition/License.txt==


   CHOLMOD/Partition Module.
   Copyright (C) 2005-2006, Univ. of Florida. Author: Timothy A. Davis
   CHOLMOD is also available under other licenses; contact authors for
   details.
   http://www.suitesparse.com

   Note that this license is for the CHOLMOD/Partition module only.
   All CHOLMOD modules are licensed separately.


   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA


   ==Supernodal/License.txt==


   CHOLMOD/Supernodal Module.
   Copyright (C) 2005-2006, Timothy A. Davis
   CHOLMOD is also available under other licenses; contact authors for
   details.
   http://www.suitesparse.com

   Note that this license is for the CHOLMOD/Supernodal module only.
   All CHOLMOD modules are licensed separately.


   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
   USA.


   ==Tcov/License.txt==


   CHOLMOD/Tcov Module. Copyright (C) 2005-2006, Timothy A. Davis
   CHOLMOD is also available under other licenses; contact authors for
   details.
   http://www.suitesparse.com

   Note that this license is for the CHOLMOD/Tcov module only.
   All CHOLMOD modules are licensed separately.


   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
   USA.

   ==Valgrind/License.txt==

   CHOLMOD/Valgrind Module. Copyright (C) 2005-2006, Timothy A. Davis.
   CHOLMOD is also available under other licenses; contact authors for
   details.
   http://www.suitesparse.com

   Note that this license is for the CHOLMOD/Valgrind module only.
   All CHOLMOD modules are licensed separately.

   This Module is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This Module is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301,
   USA.

COLAMD/Doc/License.txt
----------------------

   COLAMD, Copyright 1998-2016, Timothy A. Davis.
   http://www.suitesparse.com
   http://www.suitesparse.com

   COLAMD License: BSD 3-clause

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

-  Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

-  Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

-  Neither the name of the organizations to which the authors are
   affiliated, nor the names of its contributors may be used to endorse
   or promote products derived from this software without specific prior
   written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
   THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
   PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR
   ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
   DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
   HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
   WAY
   OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
   OF SUCH
   DAMAGE.

CSparse/Doc/License.txt
-----------------------

   CSparse: a Concise Sparse matrix package.
   Copyright (c) 2006, Timothy A. Davis.
   http://www.suitesparse.com

   CSparse is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   CSparse is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

CXSparse/Doc/License.txt
------------------------

   CXSparse: a Concise Sparse matrix package - Extended.
   Copyright (c) 2006, Timothy A. Davis.
   http://www.suitesparse.com

   CXSparse is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   CXSparse is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

CXSparse_newfiles/Doc/License.txt
---------------------------------

   CXSparse: a Concise Sparse matrix package - Extended.
   Copyright (c) 2006, Timothy A. Davis.
   http://www.suitesparse.com

   CXSparse is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   CXSparse is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

GPUQREngine/Doc/License.txt
---------------------------

   GPUQREngine Copyright (c) 2013, Timothy A. Davis, Sencer Nuri
   Yeralan,
   and Sanjay Ranka.
   http://www.suitesparse.com

   GPUQREngine is free software; you can redistribute it and/or modify
   it under
   the terms of the GNU General Public License as published by the Free
   Software
   Foundation; either version 2 of the License, or (at your option) any
   later
   version.

   GPUQREngine is distributed in the hope that it will be useful, but
   WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS
   FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
   details.

   You should have received a copy of the GNU General Public License
   along with
   this Module; if not, write to the Free Software Foundation, Inc., 51
   Franklin
   Street, Fifth Floor, Boston, MA 02110-1301, USA.

KLU/Doc/License.txt
-------------------

   KLU, Copyright (C) 2004-2013, University of Florida
   by Timothy A. Davis and Ekanathan Palamadai.
   KLU is also available under other licenses; contact authors for
   details.
   http://www.suitesparse.com

   KLU is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   KLU is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

LDL/Doc/License.txt
-------------------

   LDL Copyright (c) 2005-2013 by Timothy A. Davis.
   LDL is also available under other licenses; contact the author for
   details.
   http://www.suitesparse.com

   LDL is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   LDL is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

MATLAB_Tools/Doc/License.txt
----------------------------

   The MATLAB_Tools collection of packages is
   Copyright (c), Timothy A. Davis, All Rights Reserved,
   with the exception of the spqr_rank package, which is
   Copyright (c), Timothy A. Davis and Les Foster, All Rights Reserved,

   All packages are available under alternative licenses.
   Contact the authors for details.

   MATLAB_Tools License, with the exception of SSMULT and
   SuiteSparseCollection:

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

-  Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

-  Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

-  Neither the name of the organizations to which the authors are
   affiliated, nor the names of its contributors may be used to endorse
   or promote products derived from this software without specific prior
   written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
   THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
   PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR
   ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
   DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
   HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
   WAY
   OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
   OF SUCH
   DAMAGE.

   SuiteSparseCollection License:

   SuiteSparseCollection is free software; you can redistribute it
   and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   SuiteSparseCollection is distributed in the hope that it will be
   useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this package; if not, write to the Free Software
   Foundation,
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

   SSMULT License:

   SSMULT, Copyright (c) 2007-2011, Timothy A. Davis,
   http://www.suitesparse.com.

   SSMULT is free software; you can redistribute it and/or modify it
   under the
   terms of the GNU General Public License as published by the Free
   Software
   Foundation; either version 2 of the License, or (at your option) any
   later
   version.

   SSMULT is distributed in the hope that it will be useful, but WITHOUT
   ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS
   FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
   details.

   You should have received a copy of the GNU General Public License
   along
   with this package; if not, write to the Free Software Foundation,
   Inc., 51
   Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

RBio/Doc/License.txt
--------------------

   RBio toolbox. Copyright (C) 2006-2009, Timothy A. Davis
   RBio is also available under other licenses; contact authors for
   details.
   http://www.suitesparse.com

   RBio is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   RBio is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this Module; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

SPQR/Doc/License.txt
--------------------

   SPQR, Copyright 2008-2016 by Timothy A. Davis.
   All Rights Reserved.
   SPQR is available under alternate licenses, contact T. Davis for
   details.

   SPQR License:

   Your use or distribution of SPQR or any modified version of
   SPQR implies that you agree to this License.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

   Permission is hereby granted to use or copy this program under the
   terms of the GNU GPL, provided that the Copyright, this License,
   and the Availability of the original version is retained on all
   copies.
   User documentation of any code that uses this code or any modified
   version of this code must cite the Copyright, this License, the
   Availability note, and "Used by permission." Permission to modify
   the code and to distribute modified code is granted, provided the
   Copyright, this License, and the Availability note are retained,
   and a notice that the code was modified is included.

   Availability:

   http://www.suitesparse.com

SuiteSparse_GPURuntime/Doc/License.txt
--------------------------------------

   SuiteSparse_GPURuntime Copyright (c) 2013-2016, Timothy A. Davis,
   Sencer Nuri Yeralan, and Sanjay Ranka. http://www.suitesparse.com

   SuiteSparse_GPURuntime is free software; you can redistribute it
   and/or modify
   it under the terms of the GNU General Public License as published by
   the Free
   Software Foundation; either version 2 of the License, or (at your
   option) any
   later version.

   SuiteSparse_GPURuntime is distributed in the hope that it will be
   useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
   for more
   details.

   You should have received a copy of the GNU General Public License
   along with
   this Module; if not, write to the Free Software Foundation, Inc., 51
   Franklin
   Street, Fifth Floor, Boston, MA 02110-1301, USA.

ssget/Doc/License.txt
---------------------

   Copyright (c), 2009-2016, Timothy A. Davis, All Rights Reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

-  Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

-  Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

-  Neither the name of the organizations to which the authors are
   affiliated, nor the names of its contributors may be used to endorse
   or promote products derived from this software without specific prior
   written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
   THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
   PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR
   ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
   DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
   HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
   WAY
   OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
   OF SUCH
   DAMAGE.

UMFPACK/Doc/License.txt
-----------------------

   UMFPACK, Copyright 1995-2009 by Timothy A. Davis.
   All Rights Reserved.
   UMFPACK is available under alternate licenses, contact T. Davis for
   details.

   UMFPACK License:

   Your use or distribution of UMFPACK or any modified version of
   UMFPACK implies that you agree to this License.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
   USA

   Permission is hereby granted to use or copy this program under the
   terms of the GNU GPL, provided that the Copyright, this License,
   and the Availability of the original version is retained on all
   copies.
   User documentation of any code that uses this code or any modified
   version of this code must cite the Copyright, this License, the
   Availability note, and "Used by permission." Permission to modify
   the code and to distribute modified code is granted, provided the
   Copyright, this License, and the Availability note are retained,
   and a notice that the code was modified is included.

   Availability:

   http://www.suitesparse.com

CSparse/MATLAB/ssget/Doc/License.txt
------------------------------------

   Copyright (c), 2009-2016, Timothy A. Davis, All Rights Reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

-  Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

-  Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

-  Neither the name of the organizations to which the authors are
   affiliated, nor the names of its contributors may be used to endorse
   or promote products derived from this software without specific prior
   written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
   THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
   PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR
   ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
   DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
   HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
   WAY
   OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
   OF SUCH
   DAMAGE.

CXSparse/MATLAB/ssget/Doc/License.txt
-------------------------------------

   Copyright (c), 2009-2016, Timothy A. Davis, All Rights Reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

-  Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

-  Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

-  Neither the name of the organizations to which the authors are
   affiliated, nor the names of its contributors may be used to endorse
   or promote products derived from this software without specific prior
   written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
   THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
   PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR
   ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
   DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
   SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
   HOWEVER
   CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
   WAY
   OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
   OF SUCH
   DAMAGE.

GraphBLAS/Doc/License.txt
-------------------------

   SuiteSparse:GraphBLAS, Copyright 2017, Timothy A. Davis

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use SuiteSparse:GraphBLAS except in compliance with the
   License. You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
   implied.
   See the License for the specific language governing permissions and
   limitations under the License.


Mongoose License
----------------

   Mongoose, Copyright 2018, Timothy A. Davis, Scott P. Kolodziej,
   William W. Hager, S. Nuri Yeralan
   Licensed under the GNU GENERAL PUBLIC LICENSE, Version 3, 29 June
   2007


Type
----

standard


Dependencies
------------

- $(BLAS)
- $(MP_LIBRARY)
- :ref:`spkg_cmake`
- :ref:`spkg_gfortran`
- :ref:`spkg_mpfr`
- :ref:`spkg_ninja_build`

Version Information
-------------------

package-version.txt::

    7.8.0

See https://repology.org/project/suitesparse/versions

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i suitesparse

.. tab:: Alpine:

   .. CODE-BLOCK:: bash

       $ apk add suitesparse-dev

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S suitesparse

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install suitesparse

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install libsuitesparse-dev

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install suitesparse suitesparse-devel

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install math/suitesparse

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge sci-libs/amd sci-libs/cholmod sci-libs/suitesparseconfig \
             sci-libs/umfpack

.. tab:: Homebrew:

   .. CODE-BLOCK:: bash

       $ brew install suite-sparse

.. tab:: MacPorts:

   No package needed

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S -suitesparse

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install suitesparse-devel

.. tab:: pyodide:

   install the following packages: suitesparse

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install SuiteSparse-devel


If the system package is installed, ``./configure`` will check if it can be used.
